%define major 8
%define libname         %mklibname pythia %{major}
%define develname       %mklibname pythia -d
%global debug_package %{nil}

Name:		pythia8
Version:	8.3.03
Release:	%mkrel 1
Summary:	Pythia Event Generator for High Energy Physics
Group:		Sciences/Physics

License:	GPLv2
URL:		http://home.thep.lu.se/~torbjorn/Pythia.html
Source0:	http://home.thep.lu.se/~torbjorn/pythia8/pythia8303.tgz
###Patch0:         pythia8-makefile.patch

BuildRequires:	lhapdf-devel
BuildRequires:	hepmc-devel
buildRequires:  zlib-devel
Requires:	%{name}-data = %{version}-%{release}

%description
PYTHIA is a program for the generation of high-energy physics events, i.e.
for the description of collisions at high energies between elementary
particles such as e⁺, e⁻, p and p̄ in various combinations. It contains
theory and models for a number of physics aspects, including hard and soft
interactions, parton distributions, initial and final-state parton showers,
multiple interactions, fragmentation and decay.

%package -n %{libname}
Summary:	Pythia Event Generator for High Energy Physics
Group:		Sciences/Physics
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
PYTHIA is a program for the generation of high-energy physics events, i.e.
for the description of collisions at high energies between elementary
particles such as e⁺, e⁻, p and p̄ in various combinations. It contains
theory and models for a number of physics aspects, including hard and soft
interactions, parton distributions, initial and final-state parton showers,
multiple interactions, fragmentation and decay.

%package -n %{develname}
Summary:	Pythia 8 Development Files
Group:		Sciences/Physics
Requires:	%{libname} = %{version}-%{release}
Requires:	lhapdf-devel
Provides:       pythia8-devel = %{version}-%{release}

%description -n %{develname}
This package provides development files for Pythia 8.

%package examples
Summary:	Pythia 8 Example Source Files
Group:		Documentation
BuildArch:	noarch

%description examples
This package provides example source files for Pythia 8.

%package data
Summary:	Pythia 8 Data Files
BuildArch:	noarch
Group:		Sciences/Physics

%description data
This package provides XML data files for Pythia 8.

%package doc
Summary:	Pythia 8 Documentation Source Files
Group:		Documentation
BuildArch:	noarch

%description doc
This package provides documentation source files for Pythia 8.

%prep
%autosetup -p1 -n pythia8303

# Use the real lhapdf library
rm -rf lhapdfdummy

%build
export USRCXXFLAGS="%{optflags}"
export USRLDFLAGSSHARED="%{?__global_ldflags} -Wl,-z,defs"
%configure --enable-shared --with-hepmc=/usr \
	   --lib-suffix="-%{version}.so" \
   --with-lhapdf6 \
   --with-gzip
make %{?_smp_mflags} SHAREDSUFFIX=so.%{version}


%install
mkdir -p %{buildroot}%{_libdir}
install -m 755 lib/libpythia8-%{version}.so %{buildroot}%{_libdir}
install -m 755 lib/libpythia8lhapdf*.so %{buildroot}%{_libdir}
pushd %{buildroot}%{_libdir}
ln -s libpythia8-%{version}.so libpythia8.so
popd

mkdir -p %{buildroot}%{_includedir}/Pythia8
install -m 644 -p include/Pythia8/* %{buildroot}%{_includedir}/Pythia8
mkdir -p %{buildroot}%{_includedir}/Pythia8Plugins
install -m 644 -p include/Pythia8Plugins/* \
	%{buildroot}%{_includedir}/Pythia8Plugins

mkdir -p %{buildroot}%{_datadir}/Pythia8/xmldoc
install -m 644 -p share/Pythia8/xmldoc/* \
	%{buildroot}%{_datadir}/Pythia8/xmldoc

mkdir -p %{buildroot}%{_datadir}/Pythia8/examples
install -m 644 -p examples/* \
	%{buildroot}%{_datadir}/Pythia8/examples

%files -n %{libname}
%{_libdir}/libpythia8-%{version}.so
%doc AUTHORS COPYING GUIDELINES

%files -n %{develname}
%{_libdir}/libpythia8.so
%{_libdir}/libpythia8lhapdf*.so
%{_includedir}/Pythia8
%{_includedir}/Pythia8Plugins
%doc CODINGSTYLE

%files data
%dir %{_datadir}/Pythia8
%{_datadir}/Pythia8/xmldoc
%license COPYING

%files examples
%license COPYING
%dir %{_datadir}/Pythia8
%doc %{_datadir}/Pythia8/examples

%files doc
%doc share/Pythia8/htmldoc
%doc share/Pythia8/pdfdoc
%license COPYING


%changelog
* Fri Jan 01 2021 neoclust <neoclust> 8.3.03-1.mga8
+ Revision: 1667584
- New version 8.3.03

* Sun May 03 2020 joequant <joequant> 8.2.44-3.mga8
+ Revision: 1578344
- rebuild for i586

* Tue Apr 28 2020 joequant <joequant> 8.2.44-2.mga8
+ Revision: 1572934
- add pythia8-devel to provides

* Sat Apr 25 2020 joequant <joequant> 8.2.44-1.mga8
+ Revision: 1572132
- imported package pythia8

